==> discord_ui-3.3.3-py3-none-any.whl: discord_ui/__init__.py <==
"""
discord-ui extension
~~~~~~~~~~~~~~~~~~~~

A discord.py extension for discord's ui features like Buttons, SelectMenus, LinkButtons slash-commands and context-commands (message-commands and user-commands)

This libary features sending components, creating application-commands and receiving them

- - -

Links
    [Docs](https://discord-ui.rtfd.io/) | [Github](https://github.com/discord-py-ui/discord-ui/) | [PyPi](https://pypi.org/project/discord-ui/) | [License](https://github.com/git/git-scm.com/blob/main/MIT-LICENSE.txt)

- Made by [404kuso](https://github.com/404kuso) and [RedstoneZockt](https://github.com/RedstoneZockt)
- Made for [discord.py](https://github.com/Rapptz/discord.py) and you

- - -

### Issues, Bugs, etc.

If you find any issues, bugs, problems or anything, please report them to our [github](https://github.com/discord-py-ui/discord-ui/issues/) so we can fix them

### Ideas

If you have ideas for this package, plz feel free to tell us

### Help

If you need any help or assist, join our [discord](https://discord.gg/bDJCGD994p)

"""


from .client import Components, Slash, UI
from .components import ActionRow, Button, LinkButton, SelectMenu, SelectOption, Colors
from .slash.types import OptionType, SlashPermission, SlashOption
from .slash.tools import ParseMethod
from .tools import components_to_dict
from .receive import Interaction, InteractionType, ResponseMessage, Message, WebhookMessage, PressedButton, SelectedMenu, SlashedCommand, SlashedSubCommand, EphemeralMessage, EphemeralResponseMessage

from .override import override_dpy, override_dpy2_client
override_dpy2_client()


__title__ = "discord-ui"
__version__ = "3.3.3"

==> discord_ui-4.0.0-py3-none-any.whl: discord_ui/__init__.py <==
"""
discord-ui extension
~~~~~~~~~~~~~~~~~~~~

A discord.py extension for discord's ui features like Buttons, SelectMenus, LinkButtons slash-commands and context-commands (message-commands and user-commands)

This libary features sending components, creating application-commands and receiving them

- - -

Links
    [Docs](https://discord-ui.rtfd.io/) | [Github](https://github.com/discord-py-ui/discord-ui/) | [PyPi](https://pypi.org/project/discord-ui/) | [License](https://github.com/git/git-scm.com/blob/main/MIT-LICENSE.txt)

- Made by [404kuso](https://github.com/404kuso) and [RedstoneZockt](https://github.com/RedstoneZockt)
- Made for [discord.py](https://github.com/Rapptz/discord.py) and you

- - -

### Issues, Bugs, etc.

If you find any issues, bugs, problems or anything, please report them to our [github](https://github.com/discord-py-ui/discord-ui/issues/) so we can fix them

### Ideas

If you have ideas for this package, plz feel free to tell us

### Help

If you need any help or assist, join our [discord](https://discord.gg/bDJCGD994p)

"""


from .client import Components, Slash, UI
from .components import ActionRow, Button, LinkButton, SelectMenu, SelectOption, ButtonStyles
from .slash.types import OptionType, SlashPermission, SlashOption
from .slash.tools import ParseMethod
from .tools import components_to_dict
from .slash.tools import create_choice
from .receive import Interaction, InteractionType, Message, WebhookMessage, PressedButton, SelectedMenu, SlashedCommand, SlashedSubCommand, EphemeralMessage, EphemeralResponseMessage

from .override import override_dpy, override_dpy2_client
override_dpy2_client()


__title__ = "discord-ui"
__version__ = "4.0.0"
